@@ -1922,9 +1922,9 @@ error:
 inline void
   http_parser_init(http_parser* parser)
 {
-  void *data = parser->data; /* preserve application data */
+  //void *data = parser->data; /* preserve application data */
   memset(parser, 0, sizeof(*parser));
-  parser->data = data;
+  parser->data = NULL;//data;
   parser->state = s_start_req;
   parser->http_errno = CHPE_OK;
 }
