@@ -1,7 +1,7 @@
 test_that("User defined token", {
   testtok <- "123abc"
-  hgd(webserver=F, token=testtok)
-  hs <- hgd_state()
+  hgd(token = testtok, silent = TRUE)
+  hs <- hgd_details()
   dev.off()
   expect_equal(hs$token, testtok)
 })
@@ -12,4 +12,4 @@ test_that("Token R seed independence", {
   set.seed(1234)
   b <- hgd_generate_token(8)
   expect_false(isTRUE(all.equal(a, b)))
-})
\ No newline at end of file
+})
